## Dati stimati per una moto da 125 cc. La rapportatura del cambio sarà calcolata
## in modo da ottimizzare l'intero range di velocità.

m = 160;                      ## [kg] - massa totale veicolo + pilota
p = 1.38;                     ## [m] - passo del veicolo
b = linspace(0.4,1,30);       ## [m] - distanza baricentro dall'asse posteriore
h = linspace(0.4,1,30);       ## [m] - altezza baricentro
Rr = 0.300;                   ## [m] - raggio ruota posteriore
Rf = 0.300;                   ## [m] - raggio ruota anteriore
I_r = 0.30;                   ## [kg m^2] - Inerzia ruota posteriore
I_f = 0.36;                   ## [kg m^2] - Inerzia ruota anteriore
I_m = 0.025;                  ## [kg m^2] - Inerzia motore ridotta all'albero
I_p = 0.0025;                 ## [kg m^2] - Inerzia cambio albero primario
I_s = 0.0037;                 ## [kg m^2] - Inerzia cambio albero secondario
R_p = 1;                      ## Rapporto primario [w_albero_motore/w_primario_cambio]
R_f = 1;                      ## Rapporto finale [w_secondario_cambio/w_ruota]
## matrice coppia motore. La prima riga contiene il regime di rotazione del
## motore [rpm], la seconda riga il valore di coppia a quel regime [Nm]
CC = [6250, 6500, 6750, 7000, 7250, 7500, 7750, 8000, 8250, 8500, 8750, 9000, 9250, 9500, 9750, 10000, 10250, 10500, 10750, 11000, 11250, 11500, 11750;
      6.2, 5.4, 4.5, 5.1, 5.8, 8.4, 10.9, 12.3, 13.6, 14.1, 15.1, 15.6, 15.8, 16.3, 16.7, 17.0, 16.6, 17.3, 18.3, 18.9, 19.5, 18.6, 18];
rs = 11500;         ## [rpm] - regime di cambio marcia
Af = 0.55;          ## [m^2] - area frontale
Cd = 0.35;          ## Coefficiente di resistenza aerodinamica
Cl = 0;             ## Coefficiente di portanza aerodinamica
Cm = 0;             ## Coefficiente di momento aerodinamico. Negativo = picchiante.
                    ## Si considera già moltiplicato per la corda del profilo.
rho = 1.2;          ## [kg/m^3] - densita' dell'aria
mu = 1;             ## coefficiente di attrito gomma/asfalto
mur = 0.015;        ## coefficiente resistenza rotolamento
alpha = 0;          ## [rad] - inclinazione strada
Lr = 400;           ## [m] - lunghezza del tratto rettilineo
vi = 60/3.6;        ## [m/s] - velocita' iniziale
vf = 60/3.6;        ## [m/s] - velocita' finale
ns = 400;           ## numero di suddivisioni del tratto rettilineo
fdu = "fr";         ## freno da utilizzare
tr = "r";           ## trazione. f=front, r=rear

## Calcolo i rapporti del cambio in modo da ottimizzare l'intero range di velocità
P = CC(1,:)*2*pi/60.*CC(2,:);       ## Vettore potenze
Pm = max(P);                        ## Potenza massima [W]
rpm_Pm = max((P==Pm).*CC(1,:));     ## regime di potenza massima [rpm]
v_teor = (2*Pm/(rho*Cd*Af))^(1/3);  ## velocità massima teorica [m/s]
v_prima = Pm/m/9.8/mu;              ## Velocità desiderata in prima marcia [m/s]

## Velocità di rotazione ruota motrice
if tr =="r"
 w_6 = v_teor/Rr;
 w_1 = v_prima/Rr;
elseif tr == "f"
 w_6 = v_teor/Rf;
 w_1 = v_prima/Rr;
endif

R6 = rpm_Pm*2*pi/60/w_6;                        ## Rapporto totale sesta marcia
R1 = rpm_Pm*2*pi/60/w_1;                        ## Rapporto totale prima marcia

## Successione armonica
a = 1/R1;                                       ## Primo termine
d = (1/R6 - a)/5;                               ## Secondo termine
Rc = [1/a, 1/(a+d), 1/(a+2*d), 1/(a+3*d), 1/(a+4*d), 1/(a+5*d)];